@@ -141,7 +141,7 @@ bool ClearFormCompletionAction::action()
 bool ClearWebCacheAction::action()
 {
    const QStringList lst { QStringLiteral("--clear-all") };
-   return QProcess::startDetached(QFile::decodeName(KDE_INSTALL_FULL_LIBEXECDIR_KF5 "/kio_http_cache_cleaner"), lst);
+   return QProcess::startDetached(QFile::decodeName(KDE_INSTALL_FULL_LIBEXECDIR_KF "/kio_http_cache_cleaner"), lst);
 }
 
 bool ClearRecentDocumentsAction::action()
@@ -152,9 +152,12 @@ bool ClearRecentDocumentsAction::action()
                | Url::file();
 
    KAStats::forgetResources(query);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
    KRecentDocument::clear();
    return KRecentDocument::recentDocuments().isEmpty();
+#else
+   return true;
+#endif
 }
 
 bool ClearWebHistoryAction::action()
